@@ -1,6 +1,9 @@
 //! Request builder type for arbitrary api types
 use super::params::{DeleteParams, ListParams, Patch, PatchParams, PostParams};
 use crate::{Error, Result};
+
+pub(crate) const JSON_MIME: &str = "application/json";
+
 /// A Kubernetes request builder
 ///
 /// Takes a base_path and supplies constructors for common operations
@@ -101,7 +104,7 @@ impl Request {
             qp.append_pair("dryRun", "All");
         }
         let urlstr = qp.finish();
-        let req = http::Request::post(urlstr);
+        let req = http::Request::post(urlstr).header(http::header::CONTENT_TYPE, JSON_MIME);
         req.body(data).map_err(Error::HttpError)
     }
 
@@ -111,7 +114,7 @@ impl Request {
         let mut qp = form_urlencoded::Serializer::new(target);
         let urlstr = qp.finish();
         let body = serde_json::to_vec(&dp)?;
-        let req = http::Request::delete(urlstr);
+        let req = http::Request::delete(urlstr).header(http::header::CONTENT_TYPE, JSON_MIME);
         req.body(body).map_err(Error::HttpError)
     }
 
@@ -127,7 +130,7 @@ impl Request {
         }
         let urlstr = qp.finish();
         let body = serde_json::to_vec(&dp)?;
-        let req = http::Request::delete(urlstr);
+        let req = http::Request::delete(urlstr).header(http::header::CONTENT_TYPE, JSON_MIME);
         req.body(body).map_err(Error::HttpError)
     }
 
@@ -147,8 +150,8 @@ impl Request {
         let urlstr = qp.finish();
 
         http::Request::patch(urlstr)
-            .header("Accept", "application/json")
-            .header("Content-Type", patch.content_type())
+            .header(http::header::ACCEPT, JSON_MIME)
+            .header(http::header::CONTENT_TYPE, patch.content_type())
             .body(patch.serialize()?)
             .map_err(Error::HttpError)
     }
@@ -163,7 +166,7 @@ impl Request {
             qp.append_pair("dryRun", "All");
         }
         let urlstr = qp.finish();
-        let req = http::Request::put(urlstr);
+        let req = http::Request::put(urlstr).header(http::header::CONTENT_TYPE, JSON_MIME);
         req.body(data).map_err(Error::HttpError)
     }
 }
@@ -194,8 +197,8 @@ impl Request {
         let urlstr = qp.finish();
 
         http::Request::patch(urlstr)
-            .header("Accept", "application/json")
-            .header("Content-Type", patch.content_type())
+            .header(http::header::ACCEPT, JSON_MIME)
+            .header(http::header::CONTENT_TYPE, patch.content_type())
             .body(patch.serialize()?)
             .map_err(Error::HttpError)
     }
@@ -214,7 +217,7 @@ impl Request {
             qp.append_pair("dryRun", "All");
         }
         let urlstr = qp.finish();
-        let req = http::Request::put(urlstr);
+        let req = http::Request::put(urlstr).header(http::header::CONTENT_TYPE, JSON_MIME);
         req.body(data).map_err(Error::HttpError)
     }
 }
@@ -226,16 +229,9 @@ impl Request {
 mod test {
     use crate::{params::PostParams, request::Request, resource::Resource};
     use k8s::{
-        admissionregistration::v1beta1 as adregv1beta1,
-        apps::v1 as appsv1,
-        authorization::v1 as authv1,
-        autoscaling::v1 as autoscalingv1,
-        batch::v1beta1 as batchv1beta1,
-        core::v1 as corev1,
-        extensions::v1beta1 as extsv1beta1,
-        networking::{v1 as networkingv1, v1beta1 as networkingv1beta1},
-        rbac::v1 as rbacv1,
-        storage::v1 as storagev1,
+        admissionregistration::v1 as adregv1, apps::v1 as appsv1, authorization::v1 as authv1,
+        autoscaling::v1 as autoscalingv1, batch::v1beta1 as batchv1beta1, core::v1 as corev1,
+        networking::v1 as networkingv1, rbac::v1 as rbacv1, storage::v1 as storagev1,
     };
     use k8s_openapi::api as k8s;
     // use k8s::batch::v1 as batchv1;
@@ -249,6 +245,10 @@ mod test {
         let url = corev1::Secret::url_path(&(), Some("ns"));
         let req = Request::new(url).create(&PostParams::default(), vec![]).unwrap();
         assert_eq!(req.uri(), "/api/v1/namespaces/ns/secrets?");
+        assert_eq!(
+            req.headers().get(http::header::CONTENT_TYPE).unwrap(),
+            super::JSON_MIME
+        );
     }
 
     #[test]
@@ -294,9 +294,9 @@ mod test {
     }
     #[test]
     fn api_url_ingress() {
-        let url = extsv1beta1::Ingress::url_path(&(), Some("ns"));
+        let url = networkingv1::Ingress::url_path(&(), Some("ns"));
         let req = Request::new(url).create(&PostParams::default(), vec![]).unwrap();
-        assert_eq!(req.uri(), "/apis/extensions/v1beta1/namespaces/ns/ingresses?");
+        assert_eq!(req.uri(), "/apis/networking.k8s.io/v1/namespaces/ns/ingresses?");
     }
 
     #[test]
@@ -308,11 +308,11 @@ mod test {
 
     #[test]
     fn api_url_admission() {
-        let url = adregv1beta1::ValidatingWebhookConfiguration::url_path(&(), None);
+        let url = adregv1::ValidatingWebhookConfiguration::url_path(&(), None);
         let req = Request::new(url).create(&PostParams::default(), vec![]).unwrap();
         assert_eq!(
             req.uri(),
-            "/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations?"
+            "/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations?"
         );
     }
 
@@ -341,7 +341,6 @@ mod test {
     /// -----------------------------------------------------------------
     /// Tests that the misc mappings are also sensible
     use crate::params::{DeleteParams, ListParams, Patch, PatchParams};
-    use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1beta1 as apiextsv1beta1;
 
     #[test]
     fn list_path() {
@@ -369,6 +368,10 @@ mod test {
         };
         let req = Request::new(url).replace("myds", &pp, vec![]).unwrap();
         assert_eq!(req.uri(), "/apis/apps/v1/daemonsets/myds?&dryRun=All");
+        assert_eq!(
+            req.headers().get(http::header::CONTENT_TYPE).unwrap(),
+            super::JSON_MIME
+        );
     }
 
     #[test]
@@ -377,7 +380,11 @@ mod test {
         let dp = DeleteParams::default();
         let req = Request::new(url).delete("myrs", &dp).unwrap();
         assert_eq!(req.uri(), "/apis/apps/v1/namespaces/ns/replicasets/myrs");
-        assert_eq!(req.method(), "DELETE")
+        assert_eq!(req.method(), "DELETE");
+        assert_eq!(
+            req.headers().get(http::header::CONTENT_TYPE).unwrap(),
+            super::JSON_MIME
+        );
     }
 
     #[test]
@@ -390,7 +397,11 @@ mod test {
             req.uri(),
             "/apis/apps/v1/namespaces/ns/replicasets?&labelSelector=app%3Dmyapp"
         );
-        assert_eq!(req.method(), "DELETE")
+        assert_eq!(req.method(), "DELETE");
+        assert_eq!(
+            req.headers().get(http::header::CONTENT_TYPE).unwrap(),
+            super::JSON_MIME
+        );
     }
 
     #[test]
@@ -425,40 +436,41 @@ mod test {
             .unwrap();
         assert_eq!(req.uri(), "/api/v1/nodes/mynode/status?");
         assert_eq!(req.method(), "PUT");
+        assert_eq!(
+            req.headers().get(http::header::CONTENT_TYPE).unwrap(),
+            super::JSON_MIME
+        );
     }
 
     #[test]
     fn create_ingress() {
         // NB: Ingress exists in extensions AND networking
-        let url = networkingv1beta1::Ingress::url_path(&(), Some("ns"));
+        let url = networkingv1::Ingress::url_path(&(), Some("ns"));
         let pp = PostParams::default();
         let req = Request::new(&url).create(&pp, vec![]).unwrap();
 
-        assert_eq!(
-            req.uri(),
-            "/apis/networking.k8s.io/v1beta1/namespaces/ns/ingresses?"
-        );
+        assert_eq!(req.uri(), "/apis/networking.k8s.io/v1/namespaces/ns/ingresses?");
         let patch_params = PatchParams::default();
         let req = Request::new(url)
             .patch("baz", &patch_params, &Patch::Merge(()))
             .unwrap();
         assert_eq!(
             req.uri(),
-            "/apis/networking.k8s.io/v1beta1/namespaces/ns/ingresses/baz?"
+            "/apis/networking.k8s.io/v1/namespaces/ns/ingresses/baz?"
         );
         assert_eq!(req.method(), "PATCH");
     }
 
     #[test]
     fn replace_status() {
-        let url = apiextsv1beta1::CustomResourceDefinition::url_path(&(), None);
+        let url = apiextsv1::CustomResourceDefinition::url_path(&(), None);
         let pp = PostParams::default();
         let req = Request::new(url)
             .replace_subresource("status", "mycrd.domain.io", &pp, vec![])
             .unwrap();
         assert_eq!(
             req.uri(),
-            "/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/mycrd.domain.io/status?"
+            "/apis/apiextensions.k8s.io/v1/customresourcedefinitions/mycrd.domain.io/status?"
         );
     }
     #[test]
